@@ -8,7 +8,7 @@ from dataclasses import dataclass
 from typing import TYPE_CHECKING, Any
 
 from guidata.configtools import get_icon
-from guidata.qthelpers import win32_fix_title_bar_background
+from guidata.qthelpers import is_qobject_valid, win32_fix_title_bar_background
 from qtpy import QtCore as QC
 from qtpy import QtGui as QG
 from qtpy import QtWidgets as QW
@@ -366,14 +366,14 @@ class PlotWidget(BasePlotWidget):
 
 
 def set_widget_title_icon(
-    widget: QWidget, title: str, icon: QG.QIcon, resize: tuple[int, int] | None = None
+    widget: QWidget, title: str, icon: QG.QIcon, size: tuple[int, int] | None = None
 ) -> None:
     """Setups the widget title and icon
 
     Args:
         title: The window title
         icon: The window icon
-        resize: The window size (width, height). Defaults to None (no resize)
+        size: The window size (width, height). Defaults to None (no resize)
     """
     win32_fix_title_bar_background(widget)
     widget.setWindowTitle(title)
@@ -382,8 +382,8 @@ def set_widget_title_icon(
     if icon is not None:
         widget.setWindowIcon(icon)
     widget.setMinimumSize(320, 240)
-    if resize is not None:
-        widget.resize(*resize)
+    if size is not None:
+        widget.resize(*size)
 
 
 def add_widget_to_grid_layout(
@@ -535,6 +535,7 @@ class PlotDialog(QW.QDialog, AbstractPlotDialogWindow, metaclass=PlotDialogMeta)
         title: The window title
         icon: The window icon
         edit: If True, the plot is editable
+        size: The window size (width, height). Defaults to None (no resize)
     """
 
     def __init__(
@@ -547,9 +548,10 @@ class PlotDialog(QW.QDialog, AbstractPlotDialogWindow, metaclass=PlotDialogMeta)
         title: str = "PlotPy",
         icon: str = "plotpy.svg",
         edit: bool = False,
+        size: tuple[int, int] | None = None,
     ) -> None:
         super().__init__(parent)
-        set_widget_title_icon(self, title, icon, resize=(640, 480))
+        set_widget_title_icon(self, title, icon, size)
         self.edit = edit
         self.button_box = None
         self.button_layout = None
@@ -692,6 +694,7 @@ class PlotWindow(QW.QMainWindow, AbstractPlotDialogWindow, metaclass=PlotWindowM
          If False, the user must register the tools manually.
         title: The window title
         icon: The window icon
+        size: The window size (width, height). Defaults to None (no resize)
     """
 
     def __init__(
@@ -703,9 +706,10 @@ class PlotWindow(QW.QMainWindow, AbstractPlotDialogWindow, metaclass=PlotWindowM
         auto_tools: bool = True,
         title: str = "PlotPy",
         icon: str = "plotpy.svg",
+        size: tuple[int, int] | None = None,
     ) -> None:
         super().__init__(parent)
-        set_widget_title_icon(self, title, icon, resize=(640, 480))
+        set_widget_title_icon(self, title, icon, size)
         self.plot_layout = QW.QGridLayout()
         self.plot_widget: PlotWidget = None
         self.manager: PlotManager = None
@@ -823,7 +827,9 @@ class PlotWindow(QW.QMainWindow, AbstractPlotDialogWindow, metaclass=PlotWindowM
         # parent widget: otherwise, this panel will stay open after the main
         # window has been closed which is not the expected behavior)
         for panel in self.manager.panels:
-            self.manager.get_panel(panel).close()
+            panel_widget = self.manager.get_panel(panel)
+            if is_qobject_valid(panel_widget):
+                panel_widget.close()
         QW.QMainWindow.closeEvent(self, event)
 
 
@@ -885,55 +891,48 @@ class SubplotWidget(BasePlotWidget):
         self.manager.add_plot(plot, plot_id)
 
 
-class SyncPlotWindow(QW.QMainWindow):
-    """Window for showing plots, optionally synchronized
-
-    Args:
-        parent: parent widget
-        toolbar: show/hide toolbar
-        options: plot options
-        panels: additionnal panels
-        auto_tools: If True, the plot tools are automatically registered.
-         If False, the user must register the tools manually.
-        title: The window title
-        icon: The window icon
-
-    Usage: first, create a window, then add plots to it, then call the
-    :py:meth:`.SyncPlotWindow.finalize_configuration` method to add panels and
-    eventually register tools.
-
-    Example::
-
-        from plotpy.plot import BasePlot, SyncPlotWindow
-        win = SyncPlotWindow(title="My window")
-        plot = BasePlot()
-        win.add_plot(plot)
-        win.finalize_configuration()
-        win.show()
-    """
+class BaseSyncPlot:
+    """Base class for synchronized plot windows and dialogs"""
 
     def __init__(
         self,
-        parent: QWidget | None = None,
         toolbar: bool = True,
         options: PlotOptions | dict[str, Any] | None = None,
         auto_tools: bool = True,
         title: str = "PlotPy",
         icon: str = "plotpy.svg",
+        size: tuple[int, int] | None = None,
     ) -> None:
-        super().__init__(parent)
-        set_widget_title_icon(self, title, icon)
         self.manager = PlotManager(None)
         self.manager.set_main(self)
-        self.subplotwidget = SubplotWidget(self.manager, parent=self, options=options)
-        self.setCentralWidget(self.subplotwidget)
+        # Note: parent is not set here and widget operations on `self` are
+        # deferred to _finalize_init() because PySide6 requires the subclass's
+        # __init__ to have fully completed before widget methods can be called.
+        self.subplotwidget = SubplotWidget(self.manager, parent=None, options=options)
+        self._toolbar_visible = toolbar
+        self.auto_tools = auto_tools
+        self._rescale_timer: QC.QTimer | None = None
+        self._init_title = title
+        self._init_icon = icon
+        self._init_size = size
+
+    def _finalize_init(self) -> None:
+        """Finalize initialization after Qt widget __init__ has completed.
+
+        This is called by subclasses in their __init__ after calling both
+        QMainWindow/QDialog.__init__ and BaseSyncPlot.__init__.
+        """
         self.toolbar = QW.QToolBar(_("Tools"), self)
-        self.toolbar.setVisible(toolbar)
+        self.toolbar.setVisible(self._toolbar_visible)
         self.manager.add_toolbar(self.toolbar, "default")
         self.toolbar.setMovable(True)
         self.toolbar.setFloatable(True)
-        self.addToolBar(self.toolbar)
-        self.auto_tools = auto_tools
+        set_widget_title_icon(self, self._init_title, self._init_icon, self._init_size)
+        # Note: setup_layout() is called by subclasses after _finalize_init()
+
+    def setup_layout(self) -> None:
+        """Setup the layout - to be implemented by subclasses"""
+        raise NotImplementedError("Subclasses must implement `setup_layout` method")
 
     def get_toolbar(self) -> QW.QToolBar:
         """Return main toolbar
@@ -958,15 +957,32 @@ class SyncPlotWindow(QW.QMainWindow):
             self.subplotwidget.register_tools()
 
     def rescale_plots(self) -> None:
-        """Rescale all plots"""
+        """Rescale all plots
+
+        Note: This method is called via QTimer.singleShot, so it may be invoked
+        even after the widget starts closing. We check if rescaling is still needed.
+        """
+        # Don't rescale if timer was already stopped (widget is closing)
+        if self._rescale_timer is None or not self._rescale_timer.isActive():
+            return
+
         QW.QApplication.instance().processEvents()
         for plot in self.subplotwidget.plots:
             plot.do_autoscale()
 
-    def showEvent(self, event):  # pylint: disable=C0103
-        """Reimplement Qt method"""
-        super().showEvent(event)
-        QC.QTimer.singleShot(0, self.rescale_plots)
+    def handle_show_event(self) -> None:
+        """Handle the show event to trigger plot rescaling"""
+        # Use a QTimer instance so we can stop it if the widget is closed quickly
+        if self._rescale_timer is None:
+            self._rescale_timer = QC.QTimer(self)
+            self._rescale_timer.setSingleShot(True)
+            self._rescale_timer.timeout.connect(self.rescale_plots)
+        self._rescale_timer.start(0)
+
+    def handle_close_event(self) -> None:
+        """Handle the close event to stop pending timer"""
+        if self._rescale_timer is not None and self._rescale_timer.isActive():
+            self._rescale_timer.stop()
 
     def add_plot(
         self,
@@ -989,10 +1005,15 @@ class SyncPlotWindow(QW.QMainWindow):
             plot_id = str(len(self.subplotwidget.plots) + 1)
         self.subplotwidget.add_plot(plot, row, col, plot_id)
         if sync and len(self.subplotwidget.plots) > 1:
-            syncaxis = self.manager.synchronize_axis
-            for i_plot in range(len(self.subplotwidget.plots) - 1):
-                syncaxis(X_BOTTOM, [plot_id, f"{i_plot + 1}"])
-                syncaxis(Y_LEFT, [plot_id, f"{i_plot + 1}"])
+            self._synchronize_with_existing_plots(plot_id)
+
+    def _synchronize_with_existing_plots(self, plot_id: str) -> None:
+        """Synchronize the new plot with existing plots"""
+        syncaxis = self.manager.synchronize_axis
+        for i_plot in range(len(self.subplotwidget.plots) - 1):
+            existing_plot_id = f"{i_plot + 1}"
+            syncaxis(X_BOTTOM, [plot_id, existing_plot_id])
+            syncaxis(Y_LEFT, [plot_id, existing_plot_id])
 
     def get_plots(self) -> list[BasePlot]:
         """Return the plots
@@ -1001,3 +1022,129 @@ class SyncPlotWindow(QW.QMainWindow):
             list[BasePlot]: The plots
         """
         return self.subplotwidget.get_plots()
+
+
+class SyncPlotWindow(QW.QMainWindow, BaseSyncPlot):
+    """Window for showing plots, optionally synchronized
+
+    Args:
+        parent: parent widget
+        toolbar: show/hide toolbar
+        options: plot options
+        panels: additionnal panels
+        auto_tools: If True, the plot tools are automatically registered.
+         If False, the user must register the tools manually.
+        title: The window title
+        icon: The window icon
+        size: The window size (width, height). Defaults to None (no resize)
+
+    Usage: first, create a window, then add plots to it, then call the
+    :py:meth:`.SyncPlotWindow.finalize_configuration` method to add panels and
+    eventually register tools.
+
+    Example::
+
+        from plotpy.plot import BasePlot, SyncPlotWindow
+        win = SyncPlotWindow(title="My window")
+        plot = BasePlot()
+        win.add_plot(plot)
+        win.finalize_configuration()
+        win.show()
+    """
+
+    def __init__(
+        self,
+        parent: QWidget | None = None,
+        toolbar: bool = True,
+        options: PlotOptions | dict[str, Any] | None = None,
+        auto_tools: bool = True,
+        title: str = "PlotPy",
+        icon: str = "plotpy.svg",
+        size: tuple[int, int] | None = None,
+    ) -> None:
+        self.subplotwidget: SubplotWidget
+        self.toolbar: QW.QToolBar
+        BaseSyncPlot.__init__(self, toolbar, options, auto_tools, title, icon, size)
+        QW.QMainWindow.__init__(self, parent)
+        self._finalize_init()
+        self.setup_layout()
+
+    def showEvent(self, event):  # pylint: disable=C0103
+        """Reimplement Qt method"""
+        super().showEvent(event)
+        self.handle_show_event()
+
+    def closeEvent(self, event):  # pylint: disable=C0103
+        """Reimplement Qt method to stop pending timer before closing"""
+        self.handle_close_event()
+        super().closeEvent(event)
+
+    def setup_layout(self) -> None:
+        """Setup the main window layout"""
+        self.setCentralWidget(self.subplotwidget)
+        self.addToolBar(self.toolbar)
+
+
+class SyncPlotDialog(QW.QDialog, BaseSyncPlot):
+    """Dialog for showing plots, optionally synchronized
+
+    Args:
+        parent: parent widget
+        toolbar: show/hide toolbar
+        options: plot options
+        auto_tools: If True, the plot tools are automatically registered.
+         If False, the user must register the tools manually.
+        title: The window title
+        icon: The window icon
+        size: The window size (width, height). Defaults to None (no resize)
+
+    Usage: first, create a dialog, then add plots to it, then call the
+    :py:meth:`.SyncPlotDialog.finalize_configuration` method to add panels and
+    eventually register tools.
+
+    Example::
+
+        from plotpy.plot import BasePlot, SyncPlotDialog
+        dlg = SyncPlotDialog(title="My dialog")
+        plot = BasePlot()
+        dlg.add_plot(plot)
+        dlg.finalize_configuration()
+        dlg.exec()
+    """
+
+    def __init__(
+        self,
+        parent: QWidget | None = None,
+        toolbar: bool = True,
+        options: PlotOptions | dict[str, Any] | None = None,
+        auto_tools: bool = True,
+        title: str = "PlotPy",
+        icon: str = "plotpy.svg",
+        size: tuple[int, int] | None = None,
+    ) -> None:
+        self.subplotwidget: SubplotWidget
+        self.toolbar: QW.QToolBar
+        BaseSyncPlot.__init__(self, toolbar, options, auto_tools, title, icon, size)
+        QW.QDialog.__init__(self, parent)
+        self._finalize_init()
+        self.setup_layout()
+        self.setWindowFlags(QC.Qt.Window)
+
+    def showEvent(self, event):  # pylint: disable=C0103
+        """Reimplement Qt method"""
+        super().showEvent(event)
+        self.handle_show_event()
+
+    def closeEvent(self, event):  # pylint: disable=C0103
+        """Reimplement Qt method to stop pending timer before closing"""
+        self.handle_close_event()
+        super().closeEvent(event)
+
+    def setup_layout(self) -> None:
+        """Setup the dialog layout"""
+        self.plot_layout = QW.QGridLayout()
+        self.plot_layout.addWidget(self.subplotwidget)
+        layout = QW.QVBoxLayout()
+        layout.addWidget(self.toolbar)
+        layout.addLayout(self.plot_layout)
+        self.setLayout(layout)
