@@ -25,7 +25,7 @@ from plotpy.events import (
     setup_standard_tool_filter,
 )
 from plotpy.interfaces import ICurveItemType
-from plotpy.items import Marker, XRangeSelection
+from plotpy.items import Marker, XRangeSelection, YRangeSelection
 from plotpy.items.curve.base import CurveItem
 from plotpy.tools.base import (
     DefaultToolbarID,
@@ -36,15 +36,13 @@ from plotpy.tools.base import (
 from plotpy.tools.cursor import BaseCursorTool
 
 if TYPE_CHECKING:
-    from qwt import QwtText
-
     from plotpy.items.label import DataInfoLabel
     from plotpy.plot.base import BasePlot
     from plotpy.plot.manager import PlotManager
 
 
-class CurveStatsTool(BaseCursorTool):
-    """Curve statistics tool
+class BaseRangeCursorTool(BaseCursorTool):
+    """Base range cursor tool
 
     Args:
         manager: PlotManager Instance
@@ -56,9 +54,11 @@ class CurveStatsTool(BaseCursorTool):
          Defaults to None.
     """
 
-    TITLE = _("Signal statistics")
-    ICON = "xrange.png"
+    TITLE = ""
+    ICON = ""  # No icon by default, subclasses should set this
     SWITCH_TO_DEFAULT_TOOL = True
+    LABELFUNCS: tuple[tuple[str, Callable[..., Any]], ...] | None = None
+    SHAPECLASS: type[XRangeSelection | YRangeSelection] = XRangeSelection
 
     def __init__(
         self,
@@ -72,43 +72,20 @@ class CurveStatsTool(BaseCursorTool):
         super().__init__(manager, toolbar_id, title=title, icon=icon, tip=tip)
         self.last_item_holder = LastItemHolder(ICurveItemType)
         self.label: DataInfoLabel | None = None
-        if labelfuncs is None:
-            labelfuncs: tuple[tuple[str, Callable[..., Any]], ...] = (
-                ("%g &lt; x &lt; %g", lambda *args: (args[0].min(), args[0].max())),
-                ("%g &lt; y &lt; %g", lambda *args: (args[1].min(), args[1].max())),
-                ("&lt;y&gt;=%g", lambda *args: args[1].mean()),
-                ("σ(y)=%g", lambda *args: args[1].std()),
-                ("∑(y)=%g", lambda *args: np.sum(args[1])),
-                ("∫ydx=%g", lambda *args: spt.trapezoid(args[1], args[0])),
-            )
-        self.labelfuncs = labelfuncs
+        self.labelfuncs = labelfuncs or self.LABELFUNCS
 
-    def set_labelfuncs(
-        self, labelfuncs: tuple[tuple[str, Callable[..., Any]], ...]
-    ) -> None:
-        """Set label functions
-
-        Args:
-            labelfuncs: Label functions
-
-        Example:
-
-            .. code-block:: python
-
-                labelfuncs = (
-                    ("%g &lt; x &lt; %g", lambda *args: (args[0].min(), args[0].max())),
-                    ("%g &lt; y &lt; %g", lambda *args: (args[1].min(), args[1].max())),
-                    ("&lt;y&gt;=%g", lambda *args: args[1].mean()),
-                    ("σ(y)=%g", lambda *args: args[1].std()),
-                    ("∑(y)=%g", lambda *args: np.sum(args[1])),
-                    ("∫ydx=%g", lambda *args: spt.trapezoid(args[1], args[0])),
-                )
-        """
-        self.labelfuncs = labelfuncs
-
-    def create_shape(self) -> XRangeSelection:
+    def create_shape(self) -> XRangeSelection | YRangeSelection:
         """Create shape associated with the tool"""
-        return XRangeSelection(0, 0)
+        assert self.SHAPECLASS is not None, "SHAPECLASS must be set in subclasses"
+        return self.SHAPECLASS(0, 0)
+
+    def get_label_title(self) -> str | None:
+        """Return label title"""
+        return self.TITLE
+
+    def get_computation_specs(self):
+        """Return computation specs"""
+        raise NotImplementedError
 
     def create_label(self) -> DataInfoLabel:
         """Create label associated with the tool"""
@@ -117,10 +94,9 @@ class CurveStatsTool(BaseCursorTool):
         from plotpy.builder import make
 
         plot = self.manager.get_plot()
-        curve = self.last_item_holder.update_from_selection(plot)
-        specs = [(curve, label, func) for label, func in self.labelfuncs]
-        title: QwtText = curve.title()
-        label = make.computations(self.shape, "TL", specs, title.text())
+        title = self.get_label_title()
+        specs = self.get_computation_specs()
+        label = make.computations(self.shape, "TL", specs, title)
         label.attach(plot)
         label.setZ(plot.get_max_z() + 1)
         label.setVisible(True)
@@ -149,6 +125,67 @@ class CurveStatsTool(BaseCursorTool):
             filter.plot.add_item_with_z_offset(self.label, SHAPE_Z_OFFSET)
             self.label = None
 
+
+class CurveStatsTool(BaseRangeCursorTool):
+    """X-range curve statistics tool
+
+    Args:
+        manager: PlotManager Instance
+        toolbar_id: Toolbar Id to use. Defaults to DefaultToolbarID.
+        title: Tool name. Defaults to None.
+        icon: Tool icon path. Defaults to None.
+        tip: Available tip. Defaults to None.
+        switch_to_default_tool: Wether to use as the default tool or not.
+         Defaults to None.
+    """
+
+    TITLE = _("Signal statistics")
+    ICON = "xrange.png"
+    LABELFUNCS: tuple[tuple[str, Callable[..., Any]], ...] = (
+        ("%g &lt; x &lt; %g", lambda *args: (args[0].min(), args[0].max())),
+        ("%g &lt; y &lt; %g", lambda *args: (args[1].min(), args[1].max())),
+        ("∆x=%g", lambda *args: args[0].max() - args[0].min()),
+        ("∆y=%g", lambda *args: args[1].max() - args[1].min()),
+        ("&lt;y&gt;=%g", lambda *args: args[1].mean()),
+        ("σ(y)=%g", lambda *args: args[1].std()),
+        ("∑(y)=%g", lambda *args: np.sum(args[1])),
+        ("∫ydx=%g", lambda *args: spt.trapezoid(args[1], args[0])),
+    )
+    SHAPECLASS = XRangeSelection
+
+    def set_labelfuncs(
+        self, labelfuncs: tuple[tuple[str, Callable[..., Any]], ...]
+    ) -> None:
+        """Set label functions
+
+        Args:
+            labelfuncs: Label functions
+
+        Example:
+
+            .. code-block:: python
+
+                labelfuncs = (
+                    ("%g &lt; x &lt; %g", lambda *args: (args[0].min(), args[0].max())),
+                    ("%g &lt; y &lt; %g", lambda *args: (args[1].min(), args[1].max())),
+                    ("&lt;y&gt;=%g", lambda *args: args[1].mean()),
+                    ("σ(y)=%g", lambda *args: args[1].std()),
+                    ("∑(y)=%g", lambda *args: np.sum(args[1])),
+                    ("∫ydx=%g", lambda *args: spt.trapezoid(args[1], args[0])),
+                )
+        """
+        self.labelfuncs = labelfuncs
+
+    def get_label_title(self) -> str | None:
+        """Return label title"""
+        curve = self.last_item_holder.update_from_selection(self.manager.get_plot())
+        return curve.title().text() if curve else None
+
+    def get_computation_specs(self) -> list[tuple[CurveItem, str, Callable[..., Any]]]:
+        """Return computation specs"""
+        curve = self.last_item_holder.update_from_selection(self.manager.get_plot())
+        return [(curve, label, func) for label, func in self.labelfuncs]
+
     def update_status(self, plot: BasePlot) -> None:
         """Update tool status
 
@@ -159,6 +196,51 @@ class CurveStatsTool(BaseCursorTool):
         self.action.setEnabled(item is not None)
 
 
+class YRangeCursorTool(BaseRangeCursorTool):
+    """Y-range cursor tool
+
+    Args:
+        manager: PlotManager Instance
+        toolbar_id: Toolbar Id to use. Defaults to DefaultToolbarID.
+        title: Tool name. Defaults to None.
+        icon: Tool icon path. Defaults to None.
+        tip: Available tip. Defaults to None.
+        switch_to_default_tool: Wether to use as the default tool or not.
+         Defaults to None.
+    """
+
+    TITLE = _("Y-range")
+    ICON = "yrange.png"
+    LABELFUNCS: tuple[tuple[str, Callable[..., Any]], ...] = (
+        ("%g &lt; y &lt; %g", lambda ymin, ymax: (ymin, ymax)),
+        ("∆y=%g", lambda ymin, ymax: ymax - ymin),
+    )
+    SHAPECLASS = YRangeSelection
+
+    def set_labelfuncs(
+        self, labelfuncs: tuple[tuple[str, Callable[..., Any]], ...]
+    ) -> None:
+        """Set label functions
+
+        Args:
+            labelfuncs: Label functions
+
+        Example:
+
+            .. code-block:: python
+
+                labelfuncs = (
+                    ("%g &lt; y &lt; %g", lambda ymin, ymax: (ymin, ymax)),
+                    ("∆y=%g", lambda ymin, ymax: ymax - ymin),
+                )
+        """
+        self.labelfuncs = labelfuncs
+
+    def get_computation_specs(self) -> list[tuple[str, Callable[..., Any]]]:
+        """Return computation specs"""
+        return [(label, func) for label, func in self.labelfuncs]
+
+
 class AntiAliasingTool(ToggleTool):
     """Anti-aliasing tool
 
@@ -640,9 +722,9 @@ class SelectPointsTool(InteractiveTool):
 class InsertionDataSet(DataSet):
     """Insertion parameters"""
 
-    __index = IntItem(_("Insertion index"), min=0)
+    __index = IntItem(_("Insertion index"), min=0, default=0)
     index = __index
-    value = FloatItem(_("New value"))
+    value = FloatItem(_("New value"), default=0.0)
     index_offset = ChoiceItem(
         _("Location"), choices=[_("Before"), _("After")], default=0
     )
@@ -872,6 +954,7 @@ class EditPointTool(InteractiveTool):
                 0,
                 QC.QPointF(*new_pos),  # type: ignore
             )
+            filter.plot.replot()  # Needed on non-Windows platforms to update the view
 
     def __get_active_curve_item(self, filter: StatefulEventFilter) -> CurveItem:
         """Get active curve item. Simple method to avoid type checking errors.
@@ -1183,7 +1266,7 @@ def edit_curve_data(item: CurveItem) -> None:
 
     dialog = ArrayEditor(item.plot())
     dialog.setup_and_check(data)
-    if dialog.exec_():
+    if dialog.exec():
         if data.shape[1] > 2:
             if data.shape[1] == 3:
                 x, y, tmp = data.T
