@@ -72,7 +72,7 @@ def get_stats(
     y1: float,
 ) -> str:
     """Return formatted string with stats on image rectangular area
-    (output should be compatible with AnnotatedShape.get_infos)
+    (output should be compatible with AnnotatedShape.get_info)
 
     Args:
         item: image item
@@ -88,9 +88,16 @@ def get_stats(
         [
             "%sx%s %s" % (item.data.shape[1], item.data.shape[0], str(item.data.dtype)),
             "",
-            "%s ≤ x ≤ %s" % (p.xformat % x0, p.xformat % x1),
-            "%s ≤ y ≤ %s" % (p.yformat % y0, p.yformat % y1),
-            "%s ≤ z ≤ %s" % (p.zformat % data.min(), p.zformat % data.max()),
+            "%s ≤ x ≤ %s (Δx = %s)"
+            % (p.xformat % x0, p.xformat % x1, p.xformat % (x1 - x0)),
+            "%s ≤ y ≤ %s (Δy = %s)"
+            % (p.yformat % y0, p.yformat % y1, p.yformat % (y1 - y0)),
+            "%s ≤ z ≤ %s (Δz = %s)"
+            % (
+                p.zformat % data.min(),
+                p.zformat % data.max(),
+                p.zformat % (data.max() - data.min()),
+            ),
             "‹z› = " + p.zformat % data.mean(),
             "σ(z) = " + p.zformat % data.std(),
         ]
@@ -109,7 +116,7 @@ class ImageStatsRectangle(AnnotatedRectangle):
         stats_func: function to get statistics. Defaults to None.
          (see :py:func:`get_stats` for signature and default implementation)
         replace: True to replace stats (statistics are not added to the
-         base infos but replace them). Defaults to False.
+         base info but replace them). Defaults to False.
     """
 
     shape: PolygonShape
@@ -141,7 +148,7 @@ class ImageStatsRectangle(AnnotatedRectangle):
         self.setTitle(self.image_item.title())
 
     # ----AnnotatedShape API-----------------------------------------------------
-    def get_infos(self) -> str | None:
+    def get_info(self) -> str | None:
         """Get informations on current shape
 
         Returns:
@@ -168,14 +175,14 @@ class ImageStatsRectangle(AnnotatedRectangle):
             return _("No available data")
         x0, y0, x1, y1 = self.get_rect()
         if self.replace_stats:
-            base_infos = ""
+            base_info = ""
         else:
-            base_infos = get_stats(self.image_item, x0, y0, x1, y1)
+            base_info = get_stats(self.image_item, x0, y0, x1, y1)
         if self.stats_func is not None:
-            if base_infos:
-                base_infos += "<br>"
-            base_infos += self.stats_func(self.image_item, x0, y0, x1, y1)
-        return base_infos
+            if base_info:
+                base_info += "<br>"
+            base_info += self.stats_func(self.image_item, x0, y0, x1, y1)
+        return base_info
 
 
 class ImageStatsTool(RectangularShapeTool):
@@ -195,7 +202,7 @@ class ImageStatsTool(RectangularShapeTool):
         stats_func: function to get statistics. Defaults to None.
          (see :py:func:`get_stats` for signature and default implementation)
         replace: True to replace stats (statistics are not added to the
-         base infos but replace them). Defaults to False.
+         base info but replace them). Defaults to False.
 
     .. note:: The stats_func function should return a formatted string with
         statistics on the image rectangular area. The function signature should
@@ -257,7 +264,7 @@ class ImageStatsTool(RectangularShapeTool):
         Args:
             stats_func: function to get statistics
              (see :py:func:`get_stats` for signature and default implementation)
-            replace: True to replace stats (statistics are not added to the base infos
+            replace: True to replace stats (statistics are not added to the base info
              but replace them). Defaults to False.
         """
         self.stats_func = stats_func
@@ -423,9 +430,11 @@ class ZAxisLogTool(ToggleTool):
 class AspectRatioParam(DataSet):
     """Dataset containing aspect ratio parameters."""
 
-    lock = BoolItem(_("Lock aspect ratio"))
-    current = FloatItem(_("Current value")).set_prop("display", active=False)
-    ratio = FloatItem(_("Lock value"), min=1e-3)
+    lock = BoolItem(_("Lock aspect ratio"), default=True)
+    current = FloatItem(_("Current value"), default=1.0).set_prop(
+        "display", active=False
+    )
+    ratio = FloatItem(_("Lock value"), min=1e-3, default=1.0)
 
 
 class AspectRatioTool(CommandTool):
@@ -596,7 +605,7 @@ class ColormapTool(CommandTool):
         ):
             return
         manager = ColorMapManager(
-            plot.parent(), active_colormap=self._active_colormap.name
+            plot.parentWidget(), active_colormap=self._active_colormap.name
         )
         manager.SIG_APPLY_COLORMAP.connect(self.update_plot)
         if exec_dialog(manager) and (cmap := manager.get_colormap()) is not None:
@@ -1323,7 +1332,7 @@ class RotateCropTool(CommandTool):
             if isinstance(item, TrImageItem):
                 z = int(item.z())
                 plot.del_item(item)
-                dlg = RotateCropDialog(plot.parent(), options=self.options)
+                dlg = RotateCropDialog(plot.parentWidget(), options=self.options)
                 dlg.set_item(item)
                 ok = dlg.exec()
                 plot.add_item(item, z=z)
@@ -1363,4 +1372,4 @@ def edit_image_data(item) -> None:
     """Edit image item data in array editor"""
     dialog = ArrayEditor(item.plot())
     dialog.setup_and_check(item.data)
-    dialog.exec_()
+    dialog.exec()
